#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SPLATTED_MINIMUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SPLATTED_MINIMUM_HPP_INCLUDED

#include <boost/simd/swar/include/functions/simd/splatted_minimum.hpp>

#endif
